Summary:        LCDproc displays real-time system information on a 20x4 backlit LCD
Name:           lcdproc
Version:        0.5.3
Release:        5%{?dist}
License:        GPLv2
URL:            http://lcdproc.omnipotent.net
Group:          System Environment/Libraries
Source0:        http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.gz
Patch0:         lcdproc-0.5.3-initscripts.patch
Patch1:         lcdproc-0.5.2-novalidate.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

BuildRequires:  doxygen
BuildRequires:  graphviz

BuildRequires:  libusb-devel
BuildRequires:  lirc-devel
BuildRequires:  ncurses-devel
BuildRequires:  openldap-devel
BuildRequires:  pth-devel
BuildRequires:  xmlto
%if 0%{?fedora} > 9
BuildRequires:  docbook-dtds
%endif
BuildRequires:  xosd-devel
BuildRequires:  libX11-devel
BuildRequires:  libXext-devel
BuildRequires:  libftdi-devel

%ifarch %{ix86} x86_64
BuildRequires:  svgalib-devel
%endif

Requires(post):  /sbin/chkconfig
Requires(postun):  /sbin/chkconfig



%description
LCDproc is a client/server suite inclduding drivers for all
kinds of nifty LCD displays. The server supports several
serial devices: Matrix Orbital, Crystal Fontz, Bayrad, LB216,
LCDM001 (kernelconcepts.de), Wirz-SLI and PIC-an-LCD; and some
devices connected to the LPT port: HD44780, STV5730, T6963,
SED1520 and SED1330. Various clients are available that display
things like CPU load, system load, memory usage, uptime, and a lot more.
See also http://lcdproc.omnipotent.net.


%prep
%setup -q
%patch0 -p1 -b .initscripts
%patch1 -p1 -b .novalidate
chmod 644 server/drivers/timing.h

sed -i -e 's|server/drivers|%{_libdir}/lcdproc|' LCDd.conf
touch -r TODO LCDd.conf

%build
%configure \
  --sysconfdir=%{_sysconfdir}/sysconfig/%{name} \
  --enable-libusb \
  --enable-ldap \
  --enable-drivers=all \
  --enable-permissive-menu-goto \
  --enable-lcdproc-menus \
  --enable-stat-nfs \
  --enable-stat-smbfs \
  --with-lcdport=13666

make %{?_smp_mflags}


%install
rm -rf $RPM_BUILD_ROOT __doc
make install DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"
make install-html-guides DESTDIR=$RPM_BUILD_ROOT INSTALL="install -p"

# Fix docs
mkdir -p __doc/developer-guide
mkdir -p __doc/user-guide
install -pm 0644 $RPM_BUILD_ROOT%{_datadir}/doc/lcdproc/user-guide/*  __doc/user-guide
install -pm 0644 $RPM_BUILD_ROOT%{_datadir}/doc/lcdproc/developer-guide/*  __doc/developer-guide
rm -rf $RPM_BUILD_ROOT%{_datadir}/doc

# init
install -d $RPM_BUILD_ROOT%{_initrddir}
install -pm 0755 scripts/init-LCDd.rpm  $RPM_BUILD_ROOT%{_initrddir}/LCDd
install -pm 0755 scripts/init-lcdproc.rpm  $RPM_BUILD_ROOT%{_initrddir}/lcdproc

#Disable default configuration
#Thoses are only provided as an example since ncurses isn't a suitable default configuration.
for f in LCDd.conf lcdproc.conf ; do
mv $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}/${f} \
  $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}/${f}.example
touch $RPM_BUILD_ROOT%{_sysconfdir}/sysconfig/%{name}/${f}
done




%post
if [ $1 -eq 1 ]; then
# Add init script but don't start it
  /sbin/chkconfig --add LCDd
  /sbin/chkconfig --add lcdproc ||:
fi


%preun
if [ $1 -eq 0 ]; then
# Disable driver on final removal
  %{_initrddir}/lcdproc stop &>/dev/null
  %{_initrddir}/LCDd stop &>/dev/null
  /sbin/chkconfig --del lcdproc
  /sbin/chkconfig --del LCDd  ||:
fi


%clean
rm -rf $RPM_BUILD_ROOT __doc

%files
%defattr(-,root,root,-)
%doc README* INSTALL COPYING CREDITS TODO ChangeLog
%doc __doc/*
%{_bindir}/*
%dir %{_libdir}/lcdproc
%{_libdir}/lcdproc/*
%{_sbindir}/*
%{_mandir}/man?/*
%dir %{_sysconfdir}/sysconfig/%{name}
%ghost %{_sysconfdir}/sysconfig/%{name}/*.conf
%config %{_sysconfdir}/sysconfig/%{name}/*.conf.example
%{_initrddir}/LCDd
%{_initrddir}/lcdproc


%changelog
* Sun Apr 18 2010 Nicolas Chauvet <kwizart@fedoraproject.org> - 0.5.3-5
- Remove Uneeded BR - rhbz#572621
- Rebuild for libftdi update - rhbz#581601

* Thu Sep 10 2009 Jarod Wilson <jarod@redhat.com> - 0.5.3-4
- Add BR: libftdi-devel to build lis driver (#522270)

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.3-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Jun 25 2009 Jarod Wilson <jarod@redhat.com> - 0.5.3-2
- Fix broken LCDd initscript patch that prevented it from starting

* Mon Jun 22 2009 Jarod Wilson <jarod@redhat.com> - 0.5.3-1
- Update to lcdproc v0.5.3 release
- Drop upstreamed imonlcd and memset_swp patches
- Switch to upstream's rpm initscripts (albeit still patched, need
  to get that bit upstream for the next release)

* Wed May 13 2009 kwizart < kwizart at gmail.com > - 0.5.2-12
- Improve the initscripts patch - Fix #498384

* Tue Apr 14 2009 kwizart < kwizart at gmail.com > - 0.5.2-11
- Disable xmlto validation (Fix FTBFS)
- Disable default configuration (only provided as examples)

* Thu Mar  5 2009 kwizart < kwizart at gmail.com > - 0.5.2-10
- Disable LCDd lcdproc initscript by default.
  (It needs to be configured first).

* Mon Mar  2 2009 kwizart < kwizart at gmail.com > - 0.5.2-9
- re-enable patch0
- Prevent some timestamps changes.

* Wed Feb 25 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Nov 07 2008 Jarod Wilson <jarod@redhat.com> - 0.5.2-7
- Add SoundGraph iMon and Antec Veris LCD device support
- Replace start_daemon w/daemon in initscripts (#468611)

* Tue Jul  8 2008 kwizart < kwizart at gmail.com > - 0.5.2-6
- Add BR on Fedora > 9 : docbook-dtds

* Tue Jul  8 2008 kwizart < kwizart at gmail.com > - 0.5.2-5
- Fix RETVAL for LSB compliant initscripts - #246971
- Fix Default driver path - #454194

* Sat Feb  9 2008 kwizart < kwizart at gmail.com > - 0.5.2-4
- Rebuild for gcc43

* Sun Aug 26 2007 kwizart < kwizart at gmail.com > - 0.5.2-3
- Rebuild for BuildID

* Sun Aug 12 2007 kwizart < kwizart at gmail.com > 0.5.2-2
- Fix memset swap from djones advice
- License is GPLv2
- Fix #246971

* Sat May 19 2007 kwizart < kwizart at gmail.com > 0.5.2-1
- Update to 0.5.2
- Add BR
- Install docs

* Tue Apr 17 2007 kwizart < kwizart at gmail.com > 0.5.1-1
- Cleaned spec files for Fedora guidelines.

* Fri Sep 26 2003 TC Wan <tcwan@cs.usm.my>
- Fixed spec file for RH 9, made metar dependency optional

* Sun Oct  6 2002 Arnaud de Lorbeau <adelorbeau@mandrakesoft.com> 0.4.3-2mdk
- Add docs

* Thu Sep 12 2002 Nicolas Chipaux <chipaux@mandrakesoft.com> 0.4.3-1mdk
- new release

* Fri Oct 26 2001 Rex Dieter <rdieter@unl.edu> 0.4.1-1
- --enable-stat-smbfs
- TODO: make server/client init scripts

* Mon Oct 22 2001 Rex Dieter <rdieter@unl.edu> -0
- first try, 0.4.1 
- --enable-stat-nfs

